@@ -4,12 +4,39 @@ use std::{
 };
 use structopt::StructOpt;
 
+#[derive(StructOpt, Debug)]
+#[structopt(
+    name = "bagex",
+    global_settings(&[structopt::clap::AppSettings::ColoredHelp])
+)]
+pub struct Args {
+    #[structopt(help = "Name of executable in PATH to run")]
+    pub exe: String,
+
+    #[structopt(help = "Additional arguments to pass to executable")]
+    pub args: Vec<String>,
+
+    #[structopt(help = "Path to config file", short, long)]
+    pub config_file: Option<PathBuf>,
+
+    #[structopt(help = "Print the command to run and abort", short, long)]
+    pub dry_run: bool,
+
+    #[structopt(
+        help = "Clear environment from underlying shell for requested executable",
+        conflicts_with = "dry_run",
+        short = "e",
+        long
+    )]
+    pub clear_env: bool,
+}
+
 fn main() -> Result<(), Report> {
     log::debug!("Initializing logger and error handler ..");
     setup()?;
 
     log::debug!("Parsing command line args ..");
-    let opt = bagex::args::Args::from_args();
+    let opt = Args::from_args();
     log::trace!("Command line args read: {:#?}", opt);
 
     log::debug!("Determining path of configuration file ..");
